@@ -6,28 +6,28 @@
 # the Apache License 2.0.  The full license can be found in the LICENSE file.
 #
 
-from six import string_types, iteritems
 from datetime import date, datetime
-from .view import View
+
+from ..core.exception import PerspectiveError
 from ._accessor import _PerspectiveAccessor
 from ._callback_cache import _PerspectiveCallBackCache
-from ..core.exception import PerspectiveError
 from ._date_validator import _PerspectiveDateValidator
 from ._state import _PerspectiveStateManager
 from ._utils import (
     _dtype_to_pythontype,
     _dtype_to_str,
-    _str_to_pythontype,
     _parse_expression_strings,
+    _str_to_pythontype,
 )
 from .libbinding import (
     make_table,
-    validate_expressions,
     str_to_filter_op,
+    t_dtype,
     t_filter_op,
     t_op,
-    t_dtype,
+    validate_expressions,
 )
+from .view import View
 
 
 class Table(object):
@@ -185,7 +185,7 @@ class Table(object):
             as_string (:obj:`bool`): If True, returns the data types as string
                 representations so they can be serialized.
         """
-        validated = {"expression_schema": {}, "errors": {}}
+        validated = {"expression_schema": {}, "errors": {}, "expression_alias": {}}
 
         if len(expressions) == 0:
             return validated
@@ -195,12 +195,18 @@ class Table(object):
         expression_schema = validation_results.get_expression_schema()
         expression_errors = validation_results.get_expression_errors()
 
-        for (alias, dtype) in iteritems(expression_schema):
+        for expression in expressions:
+            # expression_alias can be used to map the alias to the
+            # full expression string in the UI.
+            validated["expression_alias"][expression[0]] = expression[1]
+
+        for (alias, dtype) in expression_schema.items():
             if not as_string:
                 dtype = _str_to_pythontype(dtype)
+
             validated["expression_schema"][alias] = expression_schema[alias]
 
-        for (alias, error) in iteritems(expression_errors):
+        for (alias, error) in expression_errors.items():
             error_dict = {}
             error_dict["error_message"] = error.error_message
             error_dict["line"] = error.line
@@ -231,7 +237,7 @@ class Table(object):
         Returns:
             :obj:`bool`: Whether this filter is valid.
         """
-        if isinstance(filter[1], string_types):
+        if isinstance(filter[1], str):
             filter_op = str_to_filter_op(filter[1])
         else:
             filter_op = filter[1]
@@ -251,7 +257,7 @@ class Table(object):
         schema = self.schema()
         in_schema = schema.get(filter[0], None)
         if in_schema and (schema[filter[0]] == date or schema[filter[0]] == datetime):
-            if isinstance(value, string_types):
+            if isinstance(value, str):
                 value = self._date_validator.parse(value)
 
         return value is not None
@@ -385,8 +391,8 @@ class Table(object):
     def view(
         self,
         columns=None,
-        row_pivots=None,
-        column_pivots=None,
+        group_by=None,
+        split_by=None,
         aggregates=None,
         sort=None,
         filter=None,
@@ -402,10 +408,10 @@ class Table(object):
         Keyword Arguments:
             columns (:obj:`list` of :obj:`str`): A list of column names to be
                 visible to the user.
-            row_pivots (:obj:`list` of :obj:`str`): A list of column names to
-                use as row pivots.
-            column_pivots (:obj:`list` of :obj:`str`): A list of column names
-                to use as column pivots.
+            group_by (:obj:`list` of :obj:`str`): A list of column names to
+                use as group by.
+            split_by (:obj:`list` of :obj:`str`): A list of column names
+                to use as split by.
             aggregates (:obj:`dict` of :obj:`str` to :obj:`str`):  A dictionary
                 of column names to aggregate types, which specify aggregates
                 for individual columns.
@@ -443,10 +449,10 @@ class Table(object):
         else:
             config["columns"] = columns
 
-        if row_pivots is not None:
-            config["row_pivots"] = row_pivots
-        if column_pivots is not None:
-            config["column_pivots"] = column_pivots
+        if group_by is not None:
+            config["group_by"] = group_by
+        if split_by is not None:
+            config["split_by"] = split_by
         if aggregates is not None:
             config["aggregates"] = aggregates
         if sort is not None:
